@@ -5,6 +5,7 @@ from hgsvn.common import (
     get_svn_rev, get_svn_rev_or_head, get_svn_rev_or_0,
     get_first_svn_log_entry, get_last_svn_log_entry,
     hg_commit_from_svn_log_entry,
+    hg_exclude_options,
 )
 
 import sys
@@ -17,6 +18,9 @@ from itertools import chain
 from optparse import OptionParser
 
 
+# TODO: an option to enable/disable svn:externals (disabled by default?)
+
+
 def main():
     usage = "usage: %prog [-r SVN rev] <SVN URL> [local hg repo]"
     parser = OptionParser(usage)
@@ -145,8 +149,9 @@ def main():
         try:
             # Add/remove new/old files
             if svn_files:
-                run_hg(["addremove", "-X.svn"] + svn_files)
-            hg_commit_from_svn_log_entry(svn_start_log, svn_files)
+                run_hg(["addremove"] + hg_exclude_options, svn_files)
+            hg_commit_from_svn_log_entry(svn_start_log)
+            #hg_commit_from_svn_log_entry(svn_start_log, svn_files)
         except:
             run_command("hg revert --all")
             raise
